==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/2f/2ff088c869f4d3c31319f3fa9238218f.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-bg_highlight-soft_75_cccccc_1x100.png */
class __TwigTemplate_b8fdb85554a111065fceba241081e2c4 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000d\000\000\000\0002\000\000\000gAMA\000\000a\000\000\000 cHRM\000\000z&\000\000\000\000\000\000\000\000\000u0\000\000`\000\000:\000\000pQ<\000\000\000bKGD1\000\000\000tIME\t
\"!\000\000\000MIDATӽΡ
@џnjn5\$@('G
iD7\\ƍ;Np
-ʜu&\000\000\000%tEXtdate:create\0002016-09-14T13:34:08-04:00_Dn\000\000\000%tEXtdate:modify\0002016-09-14T13:34:08-04:00.\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-bg_highlight-soft_75_cccccc_1x100.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-bg_highlight-soft_75_cccccc_1x100.png", "/var/www/mautic-ktn/app/bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-bg_highlight-soft_75_cccccc_1x100.png");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/2f/2ff088c869f4d3c31319f3fa9238218f.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-bg_highlight-soft_75_cccccc_1x100.png */
class __TwigTemplate_b8fdb85554a111065fceba241081e2c4 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000d\000\000\000\0002\000\000\000gAMA\000\000a\000\000\000 cHRM\000\000z&\000\000\000\000\000\000\000\000\000u0\000\000`\000\000:\000\000pQ<\000\000\000bKGD1\000\000\000tIME\t
\"!\000\000\000MIDATӽΡ
@џnjn5\$@('G
iD7\\ƍ;Np
-ʜu&\000\000\000%tEXtdate:create\0002016-09-14T13:34:08-04:00_Dn\000\000\000%tEXtdate:modify\0002016-09-14T13:34:08-04:00.\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-bg_highlight-soft_75_cccccc_1x100.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-bg_highlight-soft_75_cccccc_1x100.png", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-bg_highlight-soft_75_cccccc_1x100.png");
    }
}
